package com.hzya.frame.voucher.ae.comf.factor.service.impl;

import cn.hutool.core.lang.Assert;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hzya.frame.voucher.ae.comf.factor.entity.AeConfInfluenceFactorEntity;
import com.hzya.frame.voucher.ae.comf.factor.dao.IAeConfInfluenceFactorDao;
import com.hzya.frame.voucher.ae.comf.factor.service.IAeConfInfluenceFactorService;
import com.hzya.frame.voucher.ae.comf.module.dao.IAeConfBusinessModuleDao;
import com.hzya.frame.voucher.ae.comf.module.entity.AeConfBusinessModuleEntity;
import com.hzya.frame.voucher.ae.comf.module.service.IAeConfBusinessModuleService;
import org.springframework.beans.factory.annotation.Autowired;
import com.hzya.frame.basedao.service.impl.BaseService;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 会计事项(accounting_event)-配置-影响因素设置(AeConfInfluenceFactor)表服务实现类
 *
 * @author zydd
 * @since 2025-05-23 09:44:40
 */
@Service
public class AeConfInfluenceFactorServiceImpl extends BaseService<AeConfInfluenceFactorEntity, String> implements IAeConfInfluenceFactorService {
    private IAeConfInfluenceFactorDao aeConfInfluenceFactorDao;

    @Autowired
    public void setAeConfInfluenceFactorDao(IAeConfInfluenceFactorDao dao) {
        this.aeConfInfluenceFactorDao = dao;
        this.dao = dao;
    }

    @Autowired
    private IAeConfBusinessModuleDao aeConfBusinessModuleDao;
    @Autowired
    private IAeConfBusinessModuleService aeConfBusinessModuleService;

    @Override
    public PageInfo queryEntityPaged(AeConfInfluenceFactorEntity entity) {
        PageHelper.startPage(entity.getPageNum(), entity.getPageSize());
        List<AeConfInfluenceFactorEntity> list = aeConfInfluenceFactorDao.queryAll(entity);
        PageInfo pageInfo = new PageInfo(list);
        return pageInfo;
    }

    @Override
    public List<AeConfInfluenceFactorEntity> queryAll(AeConfInfluenceFactorEntity entity) {
        List<AeConfInfluenceFactorEntity> all = new ArrayList<>();
        all = aeConfInfluenceFactorDao.queryAll(entity);
        return all;
    }

    @Override
    public AeConfInfluenceFactorEntity queryById(AeConfInfluenceFactorEntity entity) {
        Assert.notNull(entity.getId(), "根据id查询影响因素设置时，id不能为空！！！");
        List<AeConfInfluenceFactorEntity> all = dao.query(entity);
        if (all.size() == 0) {
            return null;
        }
        return all.get(0);
    }

    @Override
    public AeConfInfluenceFactorEntity save(AeConfInfluenceFactorEntity entity) throws Exception {
        Assert.notNull(entity.getAeConfModuleId(), "保存影响因素设置时，业务模块id不能为空");
        Assert.notNull(entity.getFactorName(), "保存影响因素设置时，影响因素名称不能为空");

        updateModuleName(entity);
        return super.save(entity);
    }

    @Override
    public AeConfInfluenceFactorEntity updateById(AeConfInfluenceFactorEntity entity) {
        Assert.notNull(entity.getAeConfModuleId(), "修改影响因素设置时，业务模块id不能为空");

        AeConfInfluenceFactorEntity aeConfInfluenceFactorEntity = aeConfInfluenceFactorDao.queryById(entity);
        if (aeConfInfluenceFactorEntity == null) {
            Assert.state(false,"根据影响因素id：{}，未查询到影响因素，修改失败！",entity.getId());
        }
        //如有模块更改，需要更新此表的ae_conf_module_name模块名称
        updateModuleName(entity);

        AeConfInfluenceFactorEntity save = this.dao.save(entity);
        return save;
    }


    @Override
    public int logicRemove(AeConfInfluenceFactorEntity entity) throws Exception {
        Assert.notNull(entity.getId(), "删除影响因素设置时，影响因素id不能为空");
        return aeConfInfluenceFactorDao.logicRemove(entity);
    }

    /**
     * 根据AeConfInfluenceFactorEntity entity中的aeConfModuleId查询业务模块名称,并将名称赋值给aeConfModuleName
     *
     * @param entity
     */
    public void updateModuleName(AeConfInfluenceFactorEntity entity) {
        if (entity.getAeConfModuleId() != null || !"".equals(entity.getAeConfModuleId())) {
            AeConfBusinessModuleEntity aeConfBusinessModuleEntity = new AeConfBusinessModuleEntity();
            aeConfBusinessModuleEntity.setId(String.valueOf(entity.getAeConfModuleId()));
            AeConfBusinessModuleEntity aeConfBusinessModule = aeConfBusinessModuleService.queryById(aeConfBusinessModuleEntity);
            if (aeConfBusinessModule != null) {
                entity.setAeConfModuleName(aeConfBusinessModule.getModuleName());
            }
        }
    }


    @Override
    public List<AeConfInfluenceFactorEntity> queryFluenceFactorsByModuleId(AeConfInfluenceFactorEntity entity) {
        Assert.notNull(entity.getAeConfModuleId(), "根据业务模块id查询影响因素设置时，业务模块id不能为空");
        List<AeConfInfluenceFactorEntity> list = aeConfInfluenceFactorDao.queryAll(entity);
        return list;
    }
}
