package com.hzya.frame.voucher.ae.comf.module.service.impl;

import cn.hutool.core.lang.Assert;
import cn.hutool.json.JSONUtil;
import com.github.pagehelper.PageInfo;
import com.hzya.frame.mdm.mdmModule.dao.IMdmModuleDao;
import com.hzya.frame.mdm.mdmModule.entity.MdmModuleEntity;
import com.hzya.frame.voucher.ae.comf.module.dao.IAeConfBusinessModuleDao;
import com.hzya.frame.voucher.ae.comf.module.entity.AeConfBusinessModuleEntity;
import com.hzya.frame.voucher.ae.comf.module.entity.AeConfBusinessModuleMdmEntity;
import com.hzya.frame.voucher.ae.comf.module.dao.IAeConfBusinessModuleMdmDao;
import com.hzya.frame.voucher.ae.comf.module.service.IAeConfBusinessModuleMdmService;
import org.springframework.stereotype.Service;
import org.springframework.beans.factory.annotation.Autowired;
import com.hzya.frame.basedao.service.impl.BaseService;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 会计事项(accounting_event)-配置-业务模块-单据类型-关联(AeConfBusinessModuleBillType)表服务实现类
 *
 * @author zydd
 * @since 2025-05-23 16:31:42
 */
@Service
public class AeConfBusinessModuleMdmServiceImpl extends BaseService<AeConfBusinessModuleMdmEntity, String> implements IAeConfBusinessModuleMdmService {

    private IAeConfBusinessModuleMdmDao aeConfBusinessModuleMdmDao;

    @Autowired
    public void setaeConfBusinessModuleMdmDao(IAeConfBusinessModuleMdmDao dao) {
        this.aeConfBusinessModuleMdmDao = dao;
        this.dao = dao;
    }

    @Autowired
    private IMdmModuleDao mdmModuleDao;
    @Autowired
    private IAeConfBusinessModuleDao aeConfBusinessModuleDao;


    @Override
    public List<AeConfBusinessModuleMdmEntity> queryAll(AeConfBusinessModuleMdmEntity entity) {
        List<AeConfBusinessModuleMdmEntity> all = aeConfBusinessModuleMdmDao.query(entity);
        return all;
    }

    /**
     * 查询全部业务业务模块，里面包含主数据
     */
    @Override
    public List<AeConfBusinessModuleMdmEntity> queryModuleIncludeMdmList(AeConfBusinessModuleMdmEntity entity) {
        List<AeConfBusinessModuleMdmEntity> all = new ArrayList<>();
        List<AeConfBusinessModuleMdmEntity> aeConfBusinessModuleMdmEntityList = aeConfBusinessModuleMdmDao.query(entity);
        Map<String, List<AeConfBusinessModuleMdmEntity>> collect =
                aeConfBusinessModuleMdmEntityList.stream().collect(Collectors.groupingBy(index -> index.getAeConfModuleId() + "###" + index.getAeConfModuleName()));
        Set<Map.Entry<String, List<AeConfBusinessModuleMdmEntity>>> entries = collect.entrySet();
        for (Map.Entry<String, List<AeConfBusinessModuleMdmEntity>> entry : entries) {
            String key = entry.getKey();//moduleId###moduleName
            List<AeConfBusinessModuleMdmEntity> value = entry.getValue();
            List<MdmModuleEntity> mdmList = new ArrayList<>();
            for (AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity : value) {
                MdmModuleEntity mdmModuleEntity = new MdmModuleEntity();
                mdmModuleEntity.setMdmCode(Long.valueOf(aeConfBusinessModuleMdmEntity.getMdmCode()));
                mdmModuleEntity.setMdmName(aeConfBusinessModuleMdmEntity.getMdmName());
                mdmList.add(mdmModuleEntity);
            }

            AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity = new AeConfBusinessModuleMdmEntity();
            String[] split = key.split("###");
            aeConfBusinessModuleMdmEntity.setAeConfModuleId(Long.valueOf(split[0]));
            aeConfBusinessModuleMdmEntity.setAeConfModuleName(split[1]);
            aeConfBusinessModuleMdmEntity.setMdmModuleEntity(mdmList);
            all.add(aeConfBusinessModuleMdmEntity);
        }
        return all;
    }

    /**
     * 根据模块id查询主数据
     */
    @Override
    public List<AeConfBusinessModuleMdmEntity> queryMdmsByModuleId(AeConfBusinessModuleMdmEntity entity) {
        Assert.notNull(entity.getAeConfModuleId(), "查询主数据列表时，业务模块id不能为空");
        List<AeConfBusinessModuleMdmEntity> all = aeConfBusinessModuleMdmDao.query(entity);
        return all;
    }

    @Override
    public List<AeConfBusinessModuleMdmEntity> saveList(List<AeConfBusinessModuleMdmEntity> list) {
        if (list.size() == 0) {
            Assert.state(false, "业务模块-主数据保存时，数据不能为空，请检查！");
        }
        for (AeConfBusinessModuleMdmEntity moduleMdmEntity : list) {
            Assert.notNull(moduleMdmEntity.getAeConfModuleId(), "业务模块-主数据保存时，业务模块id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getAeConfModuleName(), "业务模块-主数据保存时，业务模块name不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmId(), "业务模块-主数据保存时，主数据id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmCode(), "业务模块-主数据保存时，主数据code不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmName(), "业务模块-主数据保存时，主数据name不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
        }
        List<AeConfBusinessModuleMdmEntity> saveList = new ArrayList<>();
        for (AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity : list) {
            AeConfBusinessModuleMdmEntity save = aeConfBusinessModuleMdmDao.save(aeConfBusinessModuleMdmEntity);
            saveList.add(save);
        }
        return saveList;
    }

    @Override
    public List<AeConfBusinessModuleMdmEntity> updateList(List<AeConfBusinessModuleMdmEntity> list) {
        if (list.size() == 0) {
            Assert.state(false, "业务模块-主数据更新时，数据不能为空，请检查！");
        }
        for (AeConfBusinessModuleMdmEntity moduleMdmEntity : list) {
            Assert.notNull(moduleMdmEntity.getId(), "业务模块-主数据保存时，业务模块-主数据id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getAeConfModuleId(), "业务模块-主数据保存时，业务模块id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getAeConfModuleName(), "业务模块-主数据保存时，业务模块name不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmId(), "业务模块-主数据保存时，主数据id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmCode(), "业务模块-主数据保存时，主数据code不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
            Assert.notNull(moduleMdmEntity.getMdmName(), "业务模块-主数据保存时，主数据name不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
        }
        List<AeConfBusinessModuleMdmEntity> updateList = new ArrayList<>();
        for (AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity : list) {
            AeConfBusinessModuleMdmEntity update = aeConfBusinessModuleMdmDao.update(aeConfBusinessModuleMdmEntity);
            updateList.add(update);
        }
        return updateList;
    }

    @Override
    public Map<String, Integer> deleteList(List<AeConfBusinessModuleMdmEntity> list) {
        if (list.size() == 0) {
            Assert.state(false, "业务模块-主数据删除时，数据不能为空，请检查！");
        }
        for (AeConfBusinessModuleMdmEntity moduleMdmEntity : list) {
            Assert.notNull(moduleMdmEntity.getId(), "业务模块-主数据删除时，业务模块-主数据id不能为空，请检查！检验数据为：{}", JSONUtil.toJsonStr(moduleMdmEntity));
        }
        Map<String, Integer> deleteMap = new HashMap<>();
        for (AeConfBusinessModuleMdmEntity aeConfBusinessModuleMdmEntity : list) {
            int i = aeConfBusinessModuleMdmDao.logicRemove(aeConfBusinessModuleMdmEntity);
            deleteMap.put(aeConfBusinessModuleMdmEntity.getId(), i);
        }
        return deleteMap;
    }


}
